<div class="panel user_menu">
    <p>{userinfo_hi}, <span>{user_name}</span></p>
    <div class="dropdown">
        <a class="dropdown-toggle" id="dLabel" role="button" data-toggle="dropdown" data-target="#" href="/page.html">
            <i class="icon-cog"></i>
        </a>
        <ul class="dropdown-menu pull-right" role="menu" aria-labelledby="dLabel">
            <li><a href="{link}/change_pass"><i class="icon-lock"></i> {menu_change_pass}</a></li>
            <li><a href="{link}/change_info"><i class="icon-user"></i> {menu_change_info}</a></li>
        </ul>
    </div>
</div>
